#!/bin/sh

#
# Init script for Catalyst FastCGI server.
# author: Robert Bohne <rbo@consol.de>
#

SERVICE_NAME='iXPaste'
ROOTPATH='/home/catalyst/iXPaste'
CGISERVER="./script/ixpaste_fastcgi.pl"
LISTEN="${ROOTPATH}/fastcgi.socket"
PIDFILE="${ROOTPATH}/fastcgi.pid"
NPROC=30
FCGIUSER='catalyst'


# Check rootpath
if [ ! -d "$ROOTPATH" ] ; then
  echo "$ROOTPATH not found"
  exit 1
fi

# Check User
WHOAMI=$(whoami)
if [ "$FCGIUSER" != "$WHOAMI" -a "$WHOAMI" != 'root' ] ; then
  echo "Please run $0 as root or $FCGIUSER!";
  exit 1
fi
# whoami for Solaris
PATH=$PATH:/usr/ucb


debugOn(){
  export DBIX_CLASS_STORAGE_DBI_DEBUG=1
  export DBIC_TRACE=1
  export CATALYST_DEBUG=1
  QUIET=''
}

debugOff(){
  unset DBIX_CLASS_STORAGE_DBI_DEBUG
  unset DBIC_TRACE
  unset CATALYST_DEBUG
  QUIET='2>&1'
}

start(){
  if [ -f "$PIDFILE" ] ; then
    PID=$(cat $PIDFILE)
    ps -p "$PID" 2>&1 1>/dev/null
    if [ $? -le 0 ] ; then
      echo "$SERVICE_NAME FastCGI daemon is running (pid $PID)"
      exit 1
    fi
    rm "$PIDFILE" 2>/dev/null
  fi
  
  if [ -e "$LISTEN" ] ; then
    rm "$LISTEN" 2>/dev/null
  fi

  START_CMD="cd $ROOTPATH && $CGISERVER -d -l $LISTEN -p $PIDFILE -n $NPROC $QUIET"

  if [ "$FCGIUSER" != "$WHOAMI" ] ; then
    START_CMD="su $FCGIUSER -c \"$START_CMD\""
  fi

  MSG=$(eval $START_CMD)

  if [ $? -gt 0 ] ; then
    echo "$SERVICE_NAME startup failed. Use startdebug for more information."
  else
    echo $SERVICE_NAME $(echo "$MSG" | tail -1)
  fi
}

stop(){
  if [ -f "$PIDFILE" ] ; then
    kill $(cat "$PIDFILE") || rm $PIDFILE
    echo "$SERVICE_NAME FastCGI daemon stopped."
  else
    echo "No pidfile!"
  fi  
}


status(){
  if [ -f $PIDFILE ] ; then
    PID=$(cat $PIDFILE)
    echo "$SERVICE_NAME FastCGI daemon is running (pid $PID) with $NPROC childs."
    exit 0
  else
    echo "No pidfile!"
    exit 1
  fi
}


case "$1" in
  start)
    debugOff
    start
    ;;
  startdebug)
    debugOn
    start
    ;;
  stop)
    stop
    ;;
  status)
    status
    ;;
  restart)
    stop
    sleep 3
    debugOff
    start
  ;;
  restartdebug)
    stop
    sleep 3
    debugOn
    start
  ;;

  *)
    echo ""
    echo "Usage: $0 [start|startdebug|stop|restart|restartdebug|status]"
    echo ""
    echo "  start - Start FastCGI daemon"
    echo "  startdebug - Start FastCGI daemon in debug mode"
    echo "  stop  - Stop FastCGI daemon"
    echo "  restart - restart FastCGI daemon"
    echo "  restartdebug - restart FastCGI daemon in debug mode"
    echo "  status - Get Status from FastCGI daemon"
    echo "  "
    echo "  Debug Mode"
    echo "  set env for DBIX and CATALYST for verbose output."
    echo "  Set:"
    echo "   - DBIX_CLASS_STORAGE_DBI_DEBUG"
    echo "   - DBIC_TRACE"
    echo "   - CATALYST_DEBUG"
    echo ""
    exit 1
esac
exit 0
