package iXPaste::Controller::Attributes;

use strict;
use warnings;
use parent 'Catalyst::Controller';

=head1 NAME

iXPaste::Controller::Attributes - Catalyst Controller

=head1 DESCRIPTION

Catalyst Controller.

=head1 METHODS

=head2 index 

Ist über /attributes erreichbar.

=cut

sub index : Path : Args(0) {
}

=head2 local

Ist über /attributes/local erreichbar.

=cut

sub local : Local {
}

=head2 global

Ist über /global erreichbar.

=cut

sub global : Global {
}

=head2 hidden

Nicht über einen HTTP-Pfad erreichbar.

=cut

sub hidden : Private {
}

=head2 list_users

Ist über /attributes/user erreichbar.

=cut

sub list_users : Path('user') : Args(0) {
}

=head2 show_user

Ist über /attributes/user/foo123 erreichbar.
Das Argument foo123 kann durch einen beliebigen String ersetzt werden.

=cut

sub show_user : Path('user') : Args(1) {
}

=head1 one

Ist über /attributes/one erreichbar.

=cut

sub one : Local {
    my ( $self, $c ) = @_;
    $c->forward('two');
}

=head2 two

Nicht über einen HTTP-Pfad erreichbar.

=cut

sub two : Private {
    my ( $self, $c ) = @_;
    $c->forward('three');
}

=head2 three

Nicht über einen HTTP-Pfad erreichbar.

=cut

sub three : Private {
}

=head2 end

=cut

sub end : Private {
    my ( $self, $c ) = @_;
    my $report = $c->stats->report;
    $c->response->body($report);
}

=head1 AUTHOR

Johannes Plunien, Thomas Pietrzykowski

=head1 LICENSE

This library is free software, you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
