package iXPaste::Controller::Paste;

use strict;
use warnings;
use parent 'Catalyst::Controller::HTML::FormFu';

=head1 NAME

iXPaste::Controller::Paste - Catalyst Controller

=head1 DESCRIPTION

Catalyst Controller.

=head1 METHODS

=head2 /paste/add

Rendert das Template root/templates/paste/add.tt
und das Formular root/forms/paste/add.yml

=cut

sub add : Path('add') : Args(0) FormConfig {
    my ( $self, $c ) = @_;
    $c->forward('set_languages');
    my $form = $c->stash->{form};
    if ( $form->submitted_and_valid ) {
        my $id = $c->model('Paste')
                   ->save($form->params);
        $c->response->redirect(
            $c->uri_for( '/paste', $id, 'shl' )
        );
    }
}

=head2 /paste/$id/$type

Zeigt den Paste-Eintrag an.

=cut

sub index : Path : Args {
    my ( $self, $c, $id, $type ) = @_;
    my $paste = $c->model('Paste')->load($id);
    if ( $paste ) {
        $c->stash->{paste} = $paste;
        if ( $type eq 'txt' ) {
            $c->forward('render_plaintext');
        }
        else {
            $c->forward('render_syntaxhighlight');
        }
    }
    else {
        $c->stash->{error} = "Die ID '$id' konnte "
                            ."nicht gefunden werden.";
    }
}

=head2 render_syntaxhighlight

Verpasst dem Paste-Eintrag Syntax-Highlighting.

=cut

sub render_syntaxhighlight : Private {
    my ( $self, $c ) = @_;
    my $paste = $c->stash->{paste};
    if ( $paste->{language} ) {
        $c->model('SyntaxHighlight')
          ->language($paste->{language});
        $paste->{content} = 
            $c->model('SyntaxHighlight')
              ->highlightText($paste->{content});
    }
}

=head2 render_plaintext

Sendet den Paste-Eintrag als reinen Text an den Browser.

=cut

sub render_plaintext : Private {
    my ( $self, $c ) = @_;
    $c->response->content_type('text/plain');
    $c->response->body($c->stash->{paste}{content});
}

=head2 set_languages

Setzt die Liste der verfuegbaren Sprachen fuers Syntax-Highlighting im Formular.

=cut

sub set_languages : Private {
    my ( $self, $c ) = @_;
    my $form      = $c->stash->{form};
    my $select    = $form->get_all_element({
                        name => 'language'
                    });
    my $options   = [ [ 0, 'Plain Text' ] ];
    my @languages = $c->model('SyntaxHighlight')
                      ->languageList;
    push @$options, map { [ $_ => $_ ] } @languages;
    $select->options($options);
}

=head1 AUTHOR

Johannes Plunien, Thomas Pietrzykowski

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
