package iXPaste::Controller::Root;

use strict;
use warnings;
use parent 'Catalyst::Controller';

#
# Sets the actions in this controller to be registered with no prefix
# so they function identically to actions created in MyApp.pm
#
__PACKAGE__->config->{namespace} = '';

=head1 NAME

iXPaste::Controller::Root - Root Controller for iXPaste

=head1 METHODS

=head2 auto

=cut

sub auto : Private {
    my ( $self, $c ) = @_;
}

=head2 index

Leitet an /paste/add weiter.

=cut

sub index : Path : Args(0) {
    my ( $self, $c ) = @_;
    $c->response->redirect( $c->uri_for('/paste/add') );
}

=head2 default

Zeigt den 404-Fehler an.

=cut

sub default : Path {
    my ( $self, $c ) = @_;
    $c->response->body('Fehler 404 - Seite nicht gefunden');
    $c->response->status(404);
}

=head2 hello_world

Rendert das Template root/templates/hello_world.tt

=cut

sub hello_world : Path('hello_world') : Args(0) {
    my ( $self, $c ) = @_;
    $c->stash->{user_agent} = $c->request->user_agent;
    $c->stash->{ip_address} = $c->request->address;
    $c->stash->{request_params} = $c->request->params;
    $c->stash->{template} = 'hello_world.tt';
    $c->forward( $c->view('TT') );
}

=head2 end

Versucht an den Standard-View weiterzuleiten falls notwendig.

=cut

sub end : ActionClass('RenderView') {
}

=head1 AUTHOR

Johannes Plunien, Thomas Pietrzykowski

=head1 LICENSE

This library is free software. You can redistribute it and/or modify
it under the same terms as Perl itself.

=cut

1;
