use strict;
use warnings;
use Test::More tests => 13;
use Test::Differences;
use HTTP::Request::Common;
use Catalyst::Test 'iXPaste';

BEGIN { use_ok 'Catalyst::Test', 'iXPaste' }
BEGIN { use_ok 'iXPaste::Controller::Paste' }

ok( request('/paste/123456/shl')->is_success, 'Request should succeed' );

{
    my $body = get( GET '/paste/123456/shl' );
    eq_or_diff( $body, <<HTML, 'ID could not be found' );
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="de" lang="de">
<head>
    <title>iXPaste</title>
    <link rel="stylesheet" href="http://localhost/static/css/screen.css" type="text/css" />
    <meta http-equiv="Content-type" content="text/html;charset=UTF-8" />
</head>
<body>
    <div id="head"><h2><a href="http://localhost/paste/add">iXPaste</a></h2></div>
    
    <div id="error">Die ID '123456' konnte nicht gefunden werden.</div>

</body>
</html>

HTML
}

{
    my $post = [
        name     => 'John Doe',
        mail     => 'john@doe.org',
        title    => 'My Test Perl Script',
        language => 'Perl',
        submit   => 'Absenden',
        content  => <<PERL
#!/usr/bin/env
use strict;
use warnings;
if (defined \$ENV{USER}) {
    printf "Hello %s\n", \$ENV{USER};
}
else {
    print "Hello World\n";
}
PERL
    ];
    action_redirect( POST '/paste/add', $post );
    my $req = POST '/paste/add', $post;
    my $res = request($req);
    my $url = $res->header('Location');
    my $got = get( GET $url );
    my ($time) = $got =~ /<td>(\d{4}-\d{2}-\d{2} \d{2}:\d{2} Uhr)<\/td>/sgi;
    my ($id)   = $url =~ qr!http://localhost/paste/(.*?)/shl!;
    my $expected = <<HTML;
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="de" lang="de">
<head>
    <title>iXPaste</title>
    <link rel="stylesheet" href="http://localhost/static/css/screen.css" type="text/css" />
    <meta http-equiv="Content-type" content="text/html;charset=UTF-8" />
</head>
<body>
    <div id="head"><h2><a href="http://localhost/paste/add">iXPaste</a></h2></div>
    
    <div class="details">
        <table class="details">
            <tr>
                <td>Datum:</td>
                <td>$time</td>
            </tr>
            
            <tr>
                <td>Sprache:</td>
                <td>Perl</td>
            </tr>
            
            <tr>
                <td>Name:</td>
                <td><a href="mailto:john\@doe.org">John Doe</a></td>
            </tr>
            <tr>
                <td>Titel:</td>
                <td>My Test Perl Script</td>
            </tr>
        </table>
    </div>
    <table class="show" cellspacing="0" cellpadding="4" border="0">
        <tr>
            <td class="code" id="lines" valign="top">
                1<br/>2<br/>3<br/>4<br/>5<br/>6<br/>7<br/>8<br/>9<br/>10<br/>11<br/>
            </td>
            
            <td class="code" valign="top"><b>#!/usr/bin/env</b><br/>
<b>use</b>&nbsp;<b>strict</b>;<br/>
<b>use</b>&nbsp;<b>warnings</b>;<br/>
<b>if</b>&nbsp;(<font color="#007f00">defined</font>&nbsp;<font color="#0000ff"><b>\$ENV</b></font>{USER})&nbsp;{<br/>
&nbsp;&nbsp;&nbsp;&nbsp;<font color="#007f00">printf</font>&nbsp;<font color="#ffa500">"</font><font color="#ff0000">Hello&nbsp;</font><font color="#0000ff">%s</font><font color="#0000ff"><br/>
</font><font color="#ffa500">"</font>,&nbsp;<font color="#0000ff"><b>\$ENV</b></font>{USER};<br/>
}<br/>
<b>else</b>&nbsp;{<br/>
&nbsp;&nbsp;&nbsp;&nbsp;<font color="#007f00">print</font>&nbsp;<font color="#ffa500">"</font><font color="#ff0000">Hello&nbsp;World</font><font color="#ff0000"><br/>
</font><font color="#ffa500">"</font>;<br/>
}<br/>
</td>
        </tr>
    </table>
    <div id="foot"><a href="http://localhost/paste/ID/txt">Als reinen Text anzeigen</a></div>

</body>
</html>

HTML

    $expected =~ s/ID/$id/;
    eq_or_diff( $got, $expected, 'Paste rendered' );
    
    $url =~ s/shl/txt/;
    $got = get( GET $url );
    $expected = <<TXT;
#!/usr/bin/env
use strict;
use warnings;
if (defined \$ENV{USER}) {
    printf "Hello %s\n", \$ENV{USER};
}
else {
    print "Hello World\n";
}
TXT
    eq_or_diff( $got, $expected, 'Paste rendered as text' );
}

for (qw/name mail title language content/) {
    my %post = (
        name     => 'John Doe',
        mail     => 'john@doe.org',
        title    => 'test',
        language => 'Perl',
        submit   => 'Absenden',
        content  => 'test',
    );
    delete $post{$_};

    my $got = get( POST '/paste/add/', [%post] );

    like( $got, qr~Feld muss ausgefüllt sein~, "$_ mandatory" );
}

{
    my $post = [
        name     => 'John Doe',
        mail     => 'invalid',
        title    => 'test',
        language => 'Perl',
        submit   => 'Absenden',
        content  => 'test',
    ];
    my $got = get( POST '/paste/add/', $post );

    like( $got, qr~Feld muss eine Email Adresse enthalten~, 'Mail valid' );
}
